@@ -1,4 +1,5 @@
 from contextlib import contextmanager
+import threading
 import time
 import functools
 import traceback
@@ -93,7 +94,6 @@ def log_action_call(action_call: ActionCall):
     actions_log_channel.push(action_call.copy())
 
 
-@log.traced
 def on_actions_logged(handler: Callable) -> Subscription:
     """Register a callback to the actions channel. It will be called before and
     after each action call. It's used for user interaction recording.
@@ -138,8 +138,7 @@ def execute_action(_action):
 
 
 def action(name: str, issuer: str = 'user'):
-    """A decorator that adds an action state emission on the start and end of
-    each function call (via fusion.gui.push_action).
+    """A decorator that registers an action and applies safety checks.
 
     On module initialization this decorator saves the decorated function in the
      actions library (by name). By registering actions and providing a stream
@@ -148,6 +147,7 @@ def action(name: str, issuer: str = 'user'):
     Args:
         name (str): The name of the action (domain-like naming convention, e.g.
          'context.action_name')
+        issuer (str): The issuer of the action.
     """
     if not name or not isinstance(name, str):
         raise Exception(
@@ -166,9 +166,16 @@ def action(name: str, issuer: str = 'user'):
             if fusion.libs.action.view_and_parent_update_ongoing():
                 raise Exception(
                     'Cannot invoke an action while updating the views.')
-                #   f' Queueing {_action} on the main loop.')
-                # gui.actions_queue_channel.push(_action)
-                # return
+
+            # If we're not on the main thread - queue the action
+            if threading.current_thread() != threading.main_thread():
+                if is_in_action():
+                    raise Exception(
+                        'It should not be possible to invoke a nested action'
+                        'From a thread different from the main one.')
+                # print(f'Not main thread. Queueing {_action}.')
+                fusion.fsm.actions_queue_channel.push(_action)
+                return
 
             return execute_action(_action)
 
